@@ -7,7 +7,7 @@ class Payload:
     def __init__(self, package, eventTime, message, tags, detail):
         self.eventId = str(uuid.uuid4())
         self.package = package
-        self.platform = Platform.python
+        self.platform = Platform.python.value
         self.eventTime = eventTime
         self.message = message
         self.tag = tags
